@@ -42,7 +42,7 @@ def Threshold(image, threshold, brightfield=True):
     return thresh#,res
 
 
-def Find_contours(thresh, minsize=200, complex_coords=False, maxsize=100000):
+def Find_contours(thresh, minsize=200, complex_coords=False, maxsize=100000, remove_edges=True, labelled=False):
     '''
     Finds the contours (or edges) of the particles in the image 
 
@@ -52,7 +52,7 @@ def Find_contours(thresh, minsize=200, complex_coords=False, maxsize=100000):
     ----------
 
         thresh:numpy array
-            The thresholded image produced by threshold()
+            The thresholded image, can be produced with threshold(). Can also use a pre-labelled image (labelled=True)
         
         minsize:int
             The minimum area (in pixels) for a particle to be considered a particle
@@ -63,6 +63,8 @@ def Find_contours(thresh, minsize=200, complex_coords=False, maxsize=100000):
         complex_coords:bool 
             Whether to use cv.CHAIN_APPROX_SIMPLE or cv.CHAIN_APPROX_NONE in the contours. Complex_coords = False (off, chain_approx_simple) simplifies the bounding coordinates leading to less total coordinates, this is faster to process. Full coordinates (complex_coords=True) allows more detailed measurements across the particle, however will take longer. 
 
+        labelled: bool
+            If you want to use a labelled image (rather than thresholded) set to true. Labelled image should have the pixels lablled a specific number for each particle 
     Returns
     -------
         contours_im:list 
@@ -72,13 +74,17 @@ def Find_contours(thresh, minsize=200, complex_coords=False, maxsize=100000):
             Binary image showing the particles selected in white and the background in black. 
 
     '''
-    cnts, hier = cv.findContours(thresh, cv.RETR_EXTERNAL, cv.CHAIN_APPROX_SIMPLE)
-    for cnt in cnts:
-        cv.drawContours(thresh, [cnt], 0,255,-1)
+
     #plt.imshow(thresh)
     #plt.show()
     #labels =measure.label(thresh, neighbors=8, background=0)
-    labels =measure.label(thresh,background=0)
+    if labelled!=True:
+        cnts, hier = cv.findContours(thresh, cv.RETR_EXTERNAL, cv.CHAIN_APPROX_SIMPLE)
+        for cnt in cnts:
+            cv.drawContours(thresh, [cnt], 0,255,-1)
+        labels =measure.label(thresh,background=0)
+    else: 
+        labels=thresh
     mask = np.zeros(thresh.shape, dtype='uint8')
     
     
@@ -93,8 +99,15 @@ def Find_contours(thresh, minsize=200, complex_coords=False, maxsize=100000):
         #if num_pixels>min_size:
         #    mask = cv.add(mask, label_mas
         coords = np.where(label_mask>0)
-        if not any([0 in coords[0], thresh.shape[0]-1 in coords[0],thresh.shape[1]-1 in coords[1], 0 in coords[1],num_pixels<minsize, num_pixels>maxsize]):
-                
+
+        #Filter out anything touching the edges
+        #if remove_edges and not any([0 in coords[0], thresh.shape[0]-1 in coords[0],thresh.shape[1]-1 in coords[1], 0 in coords[1]]):
+
+        if not any([0 in coords[0], thresh.shape[0]-1 in coords[0],thresh.shape[1]-1 in coords[1], 0 in coords[1],num_pixels<minsize, num_pixels>maxsize]) and remove_edges:
+                #print(coords)
+                mask = cv.add(mask, label_mask)
+        elif remove_edges==False and num_pixels> minsize and num_pixels<maxsize:
+                #print(coords)
                 mask = cv.add(mask, label_mask)
     if complex_coords:
         contours_im = cv.findContours(mask.copy(), cv.RETR_EXTERNAL, cv.CHAIN_APPROX_NONE)
@@ -114,8 +127,9 @@ def Find_contours(thresh, minsize=200, complex_coords=False, maxsize=100000):
 
 
 
+
     
-def Collect_particle_data(contours_im, pixelSize, multimeasure=False):    
+def Collect_particle_data(contours_im, pixel_size, multimeasure=False ):    
     '''
     This collects a number of data sets from the contours_im outputted by the find_contours function. Complex measurement of particle size can be done with multimeasure (it measures the distance across each particle at multiple points and then includes max, min, mean and std of these measurements)
 
@@ -146,7 +160,7 @@ def Collect_particle_data(contours_im, pixelSize, multimeasure=False):
  
         contours_im:list
             As generated from find_contours()
-        pixelSize:float
+        pixel_size:float
             Pixel size in the image, the same unit is used in the output data so not important here but worth keeping an eye on. 
         multimeasure:bool
             Whether to measure the distance across the particle many times, this can give an idea of the variation in shape and a better measure of diameter, but also  significantly increases runtime. 
@@ -168,6 +182,7 @@ def Collect_particle_data(contours_im, pixelSize, multimeasure=False):
     # this parameter computes the center of the mass of  particles
     centroid_x_particle =[]
     centroid_y_particle = []
+    centroid_particle = []
     # this parameter computes the ratio between maximum and minimum length of a particle
     aspect_ratio_particle = []
     # this parameter computes the perimeter of particles
@@ -196,41 +211,42 @@ def Collect_particle_data(contours_im, pixelSize, multimeasure=False):
         centroid_y=(moment_contour['m01']/moment_contour['m00'])
         centroid_x_particle.append(centroid_x)
         centroid_y_particle.append(centroid_y)
-        area = cv.contourArea(c)*pixelSize**2
+        centroid_particle.append((centroid_x, centroid_y))
+        area = cv.contourArea(c)*pixel_size**2
         area_particle.append(area)
         #meanradius_particle = area__particle[i, 0]
 
 
-        perimeter_particle.append(cv.arcLength(c, True)*pixelSize)
+        perimeter_particle.append(cv.arcLength(c, True)*pixel_size)
         min_rectangle = cv.minAreaRect(c)
         #print(min_rectangle)
         #circularity_particle = 
         width_height = min_rectangle[1]
         #print(width, height)
-        #width_particle[i, 0]= width*pixelSize
-        #height_particle[i, 0] = height*pixelSize
+        #width_particle[i, 0]= width*pixel_size
+        #height_particle[i, 0] = height*pixel_size
         height = max(width_height)
         width = min(width_height)
-        width_particle.append(width*pixelSize)
-        height_particle.append(height*pixelSize)
+        width_particle.append(width*pixel_size)
+        height_particle.append(height*pixel_size)
         MajMinRat = height/width
         MajorMinorRatio.append(MajMinRat)
         ((cx, cy), radius) = cv.minEnclosingCircle(c)
-        radius_particle.append(radius*pixelSize)
-        circularity_particle.append(area/(np.pi*radius*radius*pixelSize**2))
+        radius_particle.append(radius*pixel_size)
+        circularity_particle.append(area/(np.pi*radius*radius*pixel_size**2))
         box = cv.boxPoints(min_rectangle)
         box=np.int0(box)
 
         if multimeasure: 
             dists,coords = multiMeasure_particle(c, (centroid_x,centroid_y))
-            maxlength.append(max(dists)*pixelSize)
-            minlength.append(min(dists)*pixelSize)
-            meanlength.append(np.mean(dists)*pixelSize)
-            stddev_length.append(np.std(dists)*pixelSize)
+            maxlength.append(max(dists)*pixel_size)
+            minlength.append(min(dists)*pixel_size)
+            meanlength.append(np.mean(dists)*pixel_size)
+            stddev_length.append(np.std(dists)*pixel_size)
             measurements.append(len(dists))
     
 
-    particle_data = { 'Area':area_particle, 'Centroid_x':centroid_x_particle, 'Centroid_y':centroid_y_particle,
+    particle_data = { 'Area':area_particle, 'Centroid':centroid_particle, 'Centroid_x':centroid_x_particle, 'Centroid_y':centroid_y_particle,
                       'Perimeter':perimeter_particle, 'Circularity':circularity_particle, 
                      'Width':width_particle, 'Height':height_particle, 'Radius':radius_particle, 'Major-Minor Ratio':MajorMinorRatio}  
     if multimeasure:
@@ -339,7 +355,7 @@ def Sidebyside(Video1, Video2):
     #plt.show()
     return sidebyside
 
-def Particle_analysis(image, threshold, minsize, pixelSize,multimeasure=False):
+def Particle_analysis(image, threshold, minsize, pixel_size,multimeasure=False):
     '''
     Do the thresholding, contours finding and data collection all in one to collect data from the particles  in an image
     
@@ -351,7 +367,7 @@ def Particle_analysis(image, threshold, minsize, pixelSize,multimeasure=False):
             The threshold pixel value
         minsize:int
             minimum area of particles 
-        pixelSize:float
+        pixel_size:float
             Pixel size in the image, normally in nanometers but this unit is kept in the resulting data so it doesnt matter. 
         Multimeasure:bool
             Whether to measure the distance across the particle many times, this can give an idea of the variation in shape and a better measure of diameter, but also  significantly increases runtime. 
@@ -367,10 +383,10 @@ def Particle_analysis(image, threshold, minsize, pixelSize,multimeasure=False):
 
     thresh = Threshold(image, threshold)
     contours_im, mask = Find_contours(thresh, minsize)
-    particle_data = Collect_particle_data(contours_im, pixelSize, multimeasure)
+    particle_data = Collect_particle_data(contours_im, pixel_size, multimeasure)
     return mask, particle_data
 
-def Particle_analysis_video(video,threshold, minsize,pixelSize, multimeasure=False):
+def Particle_analysis_video(video,threshold, minsize,pixel_size, multimeasure=False):
     '''
     Runs the particle analysis for every frame in a video and creates a dictionary with a list of lists (data from each frame) as the value.  
 
@@ -382,7 +398,7 @@ def Particle_analysis_video(video,threshold, minsize,pixelSize, multimeasure=Fal
             The threshold pixel value
         minsize:int
             minimum area of particles 
-        pixelSize:float
+        pixel_size:float
             Pixel size in the image, normally in nanometers but this unit is kept in the resulting data so it doesnt matter. 
         Multimeasure:bool
             Whether to measure the distance across the particle many times, this can give an idea of the variation in shape and a better measure of diameter, but also  significantly increases runtime. 
@@ -397,23 +413,33 @@ def Particle_analysis_video(video,threshold, minsize,pixelSize, multimeasure=Fal
     '''
     masks =[]
 
-    video_data ={'Max_length':[], 'Area':[], 'Centroid':[], 
-                     'Aspect_ratio':[], 'Perimeter':[], 'Circularity':[], 
-                     'Width':[], 'Height':[], 'Radius':[], 'Major-Minor Ratio':[]}  
+    #video_data ={'Max_length':[], 'Area':[], 'Centroid':[], 
+    #                 'Aspect_ratio':[], 'Perimeter':[], 'Circularity':[], 
+    #                 'Width':[], 'Height':[], 'Radius':[], 'Major-Minor Ratio':[]}  
     
-    if multimeasure:
-        video_data['Min diameter'] = []
-        video_data['Max diameter'] = []
-        video_data['Mean diameter'] = []
-        video_data['Stddev diameter']=[]
-        video_data['Measurements']=[]
+    #if multimeasure:
+    #    video_data['Min diameter'] = []
+    #    video_data['Max diameter'] = []
+    #    video_data['Mean diameter'] = []
+    #    video_data['Stddev diameter']=[]
+    #    video_data['Measurements']=[]
     #print(particle_data)
-
+    video_data = {}
+    
+    i = 0
+    
     for frame in video:
-        mask, data =Particle_analysis(frame, threshold, minsize,pixelSize, multimeasure)
+        mask, data =Particle_analysis(frame, threshold, minsize,pixel_size, multimeasure)
         masks.append(mask)
+        
+        if i==0: 
+            for key in data.keys():
+                video_data[key]=[]
+            i=1
+
         for key in data:
             video_data[key].append(data[key])
+
     masks = np.array(masks)
     return masks, video_data
 
