@@ -1,7 +1,7 @@
 from airium import Airium
 import os
 
-def write_html(images, videos, title='Default_experiment_title', notes='', **kwargs):
+def write_html(images, videos=None, title='Default_experiment_title', notes='', **kwargs):
     '''
     Writes html file containing the images and videos from an experiment so they can be viewed on a webbrowser. This can be preferable over PDFS as the videos can be played. 
     The images and videos are only linked in this html, so in order to share the page these need to be sent as well. 
@@ -14,10 +14,10 @@ def write_html(images, videos, title='Default_experiment_title', notes='', **kwa
         Videos: list
             List of videos (including their path from the current directory), can be made with get_files()
         
-        Title:str
+        title:str
             The title for the experiment (name of html doc and title of the resulting page)
     
-        Notes:str
+        notes:str
             Accompanying notes for the experiment, included at the top of the doc.
 
     Output
